@@ -105,16 +105,15 @@ class Journal(models.Model):
         ctx = {}
         for data in self.objectdata_set.all():
             try:
-                ctx[data.tag.name] = unicode(data.content_object)
+                ctx[data.tag.name] = data.content_object
             except ObjectDoesNotExist:
-                ctx[data.tag.name] = '<deleted>'
+                ctx[data.tag.name] = '<deleted {content_type} {object_id}>'.format(
+                        content_type=data.content_type, object_id=data.object_id)
         for data in self.stringdata_set.all():
             ctx[data.tag.name] = data.content
         return ctx
 
     def __unicode__(self):
-        if len(self.message) < 125:
-            return self.message
         ctx = self.message_context()
         return self.template.content.format(**ctx)
 
